@@ -1,3 +1,5 @@
+#' @keywords internal 
+"_PACKAGE"
 #' @title Bayesian inference for Neyman-Scott point processes
 #'
 #' @description The Bayesian MCMC estimation of parameters for Thomas-type cluster
@@ -10,20 +12,22 @@
 #' Details are described in Dvořák, Remeš, Beránek & Mrkvička (2022)
 #' (\doi{10.48550/arXiv.2205.07946}).
 #'
-#' @docType package
 #' @name binspp
+# #' @aliases binspp-package
 #' @author Tomas Mrkvicka <mrkvicka.toma@gmail.com> (author),
 #' Jiri Dvorak <dvorak@karlin.mff.cuni.cz> (author),
 #' Ladislav Beranek <beranek@jcu.cz> (author),
-#' Radim Remes <inrem@jcu.cz> (author, creator)
+#' Radim Remes <inrem@jcu.cz> (author, creator),
+#' Jaewoo Park <jwpark88@yonsei.ac.kr> (contributor),
+#' Sujeong Lee <dltnwjd2304@gmail.com> (contributor)
 #'
 #' @useDynLib binspp, .registration=TRUE
 #' @import spatstat
 #' @import Rcpp
 #' @importFrom spatstat.model ppm
 #' @importFrom spatstat.geom area owin ppp im
-#' @importFrom spatstat.random rpoint rpoispp
-#' @importFrom mvtnorm rmvnorm
+#' @importFrom spatstat.random rpoint rpoispp runifpoint
+#' @importFrom mvtnorm rmvnorm pmvnorm
 #' @importFrom cluster pam
 #' @importFrom stats runif median pnorm quantile rnorm rpois vcov
 #' @importFrom graphics abline axis barplot hist lines par points
@@ -32,6 +36,8 @@
 #' @importFrom VGAM dgenpois0
 ## #' @importFrom nlme
 ## #' @importFrom spatstat
+#' @importFrom Rcpp sourceCpp
+#' @importFrom fields rdist
 #' @note
 #'     License: GPL-3
 ## #'     Encoding: UTF-8
@@ -45,7 +51,7 @@
 #'     Kopecký J., Mrkvička T. (2016). On the Bayesian estimation
 #'     for the stationary Neyman-Scott point processes,
 #'     Applications of Mathematics \strong{61}/\strong{4}, 503-514.
-#'     Available from: \url{https://am.math.cas.cz/am61-4/9.html}.
+#'     Available from: \doi{10.1007/s10492-016-0144-8}.
 #'
 #'     Dvořák, J., Remeš, R., Beránek, L., Mrkvička, T. (2022). binspp:
 #'     An R Package for Bayesian Inference for Neyman-Scott Point Processes
